@@ -1,9 +1,11 @@
 #
-# $Id: String.pm,v 0.05 2004/01/02 19:45:37 st.schubiger Exp $
+# $Id: String.pm,v 0.06 2004/01/03 22:16:32 sts Exp $
 
 package Convert::ASCII::String;
 
-use strict; 
+our $VERSION = '0.06';
+
+use strict;
 no strict 'refs';
 use warnings;
 
@@ -11,14 +13,12 @@ use Carp;
 use Exporter;
 use base qw(Exporter);
 
-our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
+our (@EXPORT_OK, %EXPORT_TAGS, @subs);
 
 @subs = qw(string2ascii ascii2string);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ( 'all' => [ @subs ] );
 
-$VERSION = '0.05';
-
 =head1 NAME
 
 Convert::ASCII::String - Convert character strings to ASCII and vice versa.
@@ -30,7 +30,6 @@ Convert::ASCII::String - Convert character strings to ASCII and vice versa.
     my $wisdom = 'Premature optimization is the root of all evil.';
 
     string2ascii (\$wisdom, '.');
-    print $wisdom;
 
       80.114.101.109.97.116.117.114.101.32.
       111.112.116.105.109.105.122.97.116.105.
@@ -39,7 +38,6 @@ Convert::ASCII::String - Convert character strings to ASCII and vice versa.
       101.118.105.108.46
 
     ascii2string (\$wisdom, '.');
-    print $wisdom;
 
       Premature optimization is the root of all evil.
 
@@ -73,7 +71,7 @@ the array. Thus string transformation with an item separator.
 
 =head1 FUNCTIONS
 
-=head2 string2ascii ( \$data, [$separator] )
+=head2 string2ascii
 
 Convert a character string to ASCII inserting a separator between each ASCII code.
 
@@ -87,7 +85,7 @@ The separator is optional.
 
 Beware, second option will not allow back converting from ASCII.
 
-=head3 RETURN CODES
+B<RETURN CODES>
 
 =over 4
 
@@ -114,13 +112,13 @@ sub string2ascii {
     return 1;
 }
 
-=head2 ascii2string ( \$data, $separator )
+=head2 ascii2string
 
 And vice versa.
 
     ascii2string (\$data, '.');
 
-=head3 RETURN CODES
+B<RETURN CODES>
 
 =over 4
 
@@ -172,6 +170,8 @@ Function delivery becomes then superfluous.
 
 C<string2ascii()>
 
+=item *
+
 C<ascii2string()>
 
 =back
@@ -180,9 +180,9 @@ C<ascii2string()>
 
 =over 4
 
-=item :all 
+=item *
 
-C<*()>
+C<:all  - *()>
 
 =back
 
